@@ -7,7 +7,7 @@ mdmb_regression_summary <- function( object , digits = 4 , file=NULL , ...){
 	type <- object$type
 
     # open sink
-    CDM::osink( file = file , suffix = paste0( file, "__SUMMARY.Rout") )
+    CDM::osink( file = file , suffix = paste0( "__SUMMARY.Rout") )
 
 	cat("-----------------------------------------------------------------\n")
     d1 <- utils::packageDescription("mdmb")
