@@ -5,7 +5,7 @@
 summary.frm_em <- function( object , digits = 4 , file=NULL , ...){
 
     # open sink
-    CDM::osink( file = file , suffix = paste0( file, "__SUMMARY.Rout") )
+    CDM::osink( file = file , suffix = paste0( "__SUMMARY.Rout") )
 
 	cat("-----------------------------------------------------------------\n")
     d1 <- utils::packageDescription("mdmb")
